@@ -20,9 +20,6 @@
   | - Jonathan Tansavatdi                                                |
   +----------------------------------------------------------------------+
 */
-
-/* $Id: amqp_queue.c 327551 2012-09-09 03:49:34Z pdezwart $ */
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -53,6 +50,7 @@
 #include "amqp_connection.h"
 #include "amqp_channel.h"
 #include "amqp_queue.h"
+#include "amqp_type.h"
 
 zend_class_entry *amqp_queue_class_entry;
 #define this_ce amqp_queue_class_entry
@@ -315,7 +313,7 @@ static PHP_METHOD(amqp_queue_class, declareQueue)
 	channel_resource = PHP_AMQP_GET_CHANNEL_RESOURCE(PHP_AMQP_READ_THIS_PROP("channel"));
 	PHP_AMQP_VERIFY_CHANNEL_RESOURCE(channel_resource, "Could not declare queue.");
 
-	arguments = convert_zval_to_amqp_table(PHP_AMQP_READ_THIS_PROP("arguments") TSRMLS_CC);
+	arguments = php_amqp_type_convert_zval_to_amqp_table(PHP_AMQP_READ_THIS_PROP("arguments") TSRMLS_CC);
 
 	amqp_queue_declare_ok_t *r = amqp_queue_declare(
 		channel_resource->connection_resource->connection_state,
@@ -328,7 +326,7 @@ static PHP_METHOD(amqp_queue_class, declareQueue)
 		*arguments
 	);
 
-	php_amqp_free_amqp_table(arguments);
+	php_amqp_type_free_amqp_table(arguments);
 
 	if (!r) {
 		amqp_rpc_reply_t res = amqp_get_rpc_reply(channel_resource->connection_resource->connection_state);
@@ -343,7 +341,7 @@ static PHP_METHOD(amqp_queue_class, declareQueue)
 	message_count = r->message_count;
 
 	/* Set the queue name, in case it is an autogenerated queue name */
-	name = stringify_bytes(r->queue);
+	name = php_amqp_type_amqp_bytes_to_char(r->queue);
 	zend_update_property_string(this_ce, getThis(), ZEND_STRL("name"), name TSRMLS_CC);
 	efree(name);
 
@@ -381,7 +379,7 @@ static PHP_METHOD(amqp_queue_class, bind)
 	PHP_AMQP_VERIFY_CHANNEL_RESOURCE(channel_resource, "Could not bind queue.");
 
 	if (zvalArguments) {
-		arguments = convert_zval_to_amqp_table(zvalArguments TSRMLS_CC);
+		arguments = php_amqp_type_convert_zval_to_amqp_table(zvalArguments TSRMLS_CC);
 	}
 
 	amqp_queue_bind(
@@ -394,7 +392,7 @@ static PHP_METHOD(amqp_queue_class, bind)
 	);
 
 	if (arguments) {
-		php_amqp_free_amqp_table(arguments);
+		php_amqp_type_free_amqp_table(arguments);
 	}
 
 	amqp_rpc_reply_t res = amqp_get_rpc_reply(channel_resource->connection_resource->connection_state);
@@ -527,7 +525,7 @@ static PHP_METHOD(amqp_queue_class, consume)
 
 	if (!(AMQP_JUST_CONSUME & flags)) {
 		/* Setup the consume */
-		arguments = convert_zval_to_amqp_table(PHP_AMQP_READ_THIS_PROP("arguments") TSRMLS_CC);
+		arguments = php_amqp_type_convert_zval_to_amqp_table(PHP_AMQP_READ_THIS_PROP("arguments") TSRMLS_CC);
 
 		amqp_basic_consume_ok_t *r = amqp_basic_consume(
 				channel_resource->connection_resource->connection_state,
@@ -540,7 +538,7 @@ static PHP_METHOD(amqp_queue_class, consume)
 				*arguments
 		);
 
-		php_amqp_free_amqp_table(arguments);
+		php_amqp_type_free_amqp_table(arguments);
 
 		if (!r) {
 			amqp_rpc_reply_t res = amqp_get_rpc_reply(channel_resource->connection_resource->connection_state);
@@ -918,7 +916,7 @@ static PHP_METHOD(amqp_queue_class, unbind)
 	PHP_AMQP_VERIFY_CHANNEL_RESOURCE(channel_resource, "Could not unbind queue.");
 
 	if (zvalArguments) {
-		arguments = convert_zval_to_amqp_table(zvalArguments TSRMLS_CC);
+		arguments = php_amqp_type_convert_zval_to_amqp_table(zvalArguments TSRMLS_CC);
 	}
 
 	amqp_queue_unbind(
@@ -931,7 +929,7 @@ static PHP_METHOD(amqp_queue_class, unbind)
 	);
 
 	if (arguments) {
-		php_amqp_free_amqp_table(arguments);
+		php_amqp_type_free_amqp_table(arguments);
 	}
 
 	amqp_rpc_reply_t res = amqp_get_rpc_reply(channel_resource->connection_resource->connection_state);
